<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Tripwires Index

Complete index of category-specific tripwire files.

## Universal Tripwires

Load **first** for any code area: [universal-tripwires.md](universal-tripwires.md)

## Category Tripwires

| Category                                    | Tripwires | Load When Working In                     |
| ------------------------------------------- | --------- | ---------------------------------------- |
| [architecture](architecture/tripwires.md)   | 178       | `src/erk/gateway/`, gateways, subprocess |
| [capabilities](capabilities/tripwires.md)   | 13        | Claude Code capabilities, tool use       |
| [changelog](changelog/tripwires.md)         | 3         | `changelog/` code                        |
| [checklists](checklists/tripwires.md)       | 1         | `checklists/` code                       |
| [ci](ci/tripwires.md)                       | 54        | `.github/workflows/`, `.github/actions/` |
| [claude-code](claude-code/tripwires.md)     | 3         | Claude Code configuration, settings      |
| [cli](cli/tripwires.md)                     | 82        | `src/erk/cli/`                           |
| [commands](commands/tripwires.md)           | 7         | `.claude/commands/`, slash commands      |
| [config](config/tripwires.md)               | 2         | `config/` code                           |
| [configuration](configuration/tripwires.md) | 1         | `configuration/` code                    |
| [documentation](documentation/tripwires.md) | 30        | `documentation/` code                    |
| [erk](erk/tripwires.md)                     | 22        | `erk/` code                              |
| [gateway](gateway/tripwires.md)             | 5         | `gateway/` code                          |
| [hooks](hooks/tripwires.md)                 | 4         | `.claude/hooks/`, hook development       |
| [integrations](integrations/tripwires.md)   | 26        | `integrations/` code                     |
| [objectives](objectives/tripwires.md)       | 45        | `objectives/` code                       |
| [planning](planning/tripwires.md)           | 124       | `.erk/impl-context/`, planning workflows |
| [pr-operations](pr-operations/tripwires.md) | 17        | `pr-operations/` code                    |
| [refactoring](refactoring/tripwires.md)     | 14        | `refactoring/` code                      |
| [reference](reference/tripwires.md)         | 15        | `reference/` code                        |
| [review](review/tripwires.md)               | 3         | `review/` code                           |
| [reviews](reviews/tripwires.md)             | 4         | `reviews/` code                          |
| [sessions](sessions/tripwires.md)           | 10        | `~/.claude/projects/`, session analysis  |
| [testing](testing/tripwires.md)             | 66        | `tests/`                                 |
| [textual](textual/tripwires.md)             | 1         | Textual framework code                   |
| [tui](tui/tripwires.md)                     | 58        | `src/erk/tui/`                           |
| [uncategorized](uncategorized/tripwires.md) | 15        | `uncategorized/` code                    |
| [workflows](workflows/tripwires.md)         | 6         | `workflows/` code                        |
